package net.cattaka.rdbassistant.gui;


import javax.swing.JTabbedPane;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import net.cattaka.rdbassistant.RdbaMessageConstants;
import net.cattaka.rdbassistant.bean.RdbaSingletonBundle;
import net.cattaka.rdbassistant.config.RdbaConfig;
import net.cattaka.rdbassistant.core.RdbaConnection;
import net.cattaka.rdbassistant.gui.script.RdbaScriptModePanel;
import net.cattaka.rdbassistant.gui.sql.RdbaSqlModePanel;
import net.cattaka.util.MessageBundle;

public class RdbaModeTabbedPanel extends JTabbedPane implements RdbaGuiInterface {
	private static final long serialVersionUID = 1L;
	
	private RdbaSqlModePanel rdbaSqlModePanel;
	private RdbaScriptModePanel rdbaScriptModePanel;
	private RdbaConnection rdbConnection;
	private RdbaGuiInterface parentComponent;

	class ChangeListenerImpl implements ChangeListener {
		public void stateChanged(ChangeEvent e) {
			sendRdbaMessage(new RdbaMessage(RdbaMessageConstants.RDBAASSISTANTPANEL_UPDATEMENU, null, RdbaModeTabbedPanel.this, null));
		}
	}
	
	public RdbaModeTabbedPanel(RdbaGuiInterface parentComponent) {
		this.parentComponent = parentComponent;
		makeLayout();
	}

	private void makeLayout() {
		this.rdbaSqlModePanel = new RdbaSqlModePanel(this.parentComponent);
		this.rdbaScriptModePanel = new RdbaScriptModePanel(this.parentComponent);
		
		this.add(MessageBundle.getMessage("sql"), this.rdbaSqlModePanel);
		this.add(MessageBundle.getMessage("script"), this.rdbaScriptModePanel);

		// タブ操作についての処理を追加
		this.addChangeListener(new ChangeListenerImpl());
	}

	public void setRdbConnection(RdbaConnection rdbConnection) {
		this.rdbConnection = rdbConnection;
		this.rdbaSqlModePanel.setRdbConnection(this.rdbConnection);
		this.rdbaScriptModePanel.setRdbConnection(this.rdbConnection);
	}
	
	public void doGuiLayout() {
		this.rdbaSqlModePanel.doGuiLayout();
		this.rdbaScriptModePanel.doGuiLayout();
	}
	
	public void reloadRdbaConfig() {
		this.rdbaSqlModePanel.reloadRdbaConfig();
		this.rdbaScriptModePanel.reloadRdbaConfig();
	}
	
	public RdbaConfig getRdbaConfig() {
		return this.parentComponent.getRdbaConfig();
	}

	public void sendRdbaMessage(RdbaMessage rdbaMessage) {
		this.parentComponent.sendRdbaMessage(rdbaMessage);
	}
	public void relayRdbaMessage(RdbaMessage rbdaMessage) {
		this.rdbaSqlModePanel.relayRdbaMessage(rbdaMessage);
		this.rdbaScriptModePanel.relayRdbaMessage(rbdaMessage);
	}
	public RdbaSingletonBundle getRdbaSingletonBundle() {
		return this.parentComponent.getRdbaSingletonBundle();
	}
}
