package net.cattaka.rdbassistant.oracle;

import java.sql.Connection;
import java.sql.Driver;
import java.sql.SQLException;
import java.util.Properties;

import net.cattaka.rdbassistant.RdbaConfigConstants;
import net.cattaka.rdbassistant.config.RdbaConnectionInfo;
import net.cattaka.rdbassistant.config.RdbaJdbcBundle;
import net.cattaka.rdbassistant.core.RdbaException;
import net.cattaka.rdbassistant.core.RdbaConnection;
import net.cattaka.rdbassistant.gui.connectioninfo.RdbaConnectionInfoEditor;

public class OracleRdbaConnectionInfo implements RdbaConnectionInfo {
	private static final long serialVersionUID = 1L;
	
	private String host = "";
	private Integer port = new Integer(1521);
	private String sid = "";
	private String userName = "";
	private String password = "";
	private String label = "";
	
	public String toUrl() {
		return String.format("jdbc:oracle:thin:@%s:%d:%s", host, port, sid);
	}
	
	public RdbaConnection createConnection(RdbaJdbcBundle rdbaJdbcBundle) throws RdbaException {
		Driver driver = null;
		driver = rdbaJdbcBundle.getDriver(RdbaConfigConstants.DRIVER_JDBC_ORACLE, "oracle.jdbc.driver.OracleDriver");
		
		Connection conn = null;
		try {
			Properties info = new Properties();
			info.setProperty("user", userName);
			info.setProperty("password", password);
			conn = driver.connect(toUrl(), info);
			conn.setAutoCommit(false);
		} catch (SQLException e) {
			throw new RdbaException(e.getMessage(),e);
		}
		
		OracleRdbaConnection rdbaConnection = new OracleRdbaConnection(conn, userName);
		
		return rdbaConnection;
	}

	public String[] getDisplayStrings() {
		return new String[]{"Oracle",label, host+":"+sid,userName};
	}

	public String getTooltipText() {
		return String.format("%s@%s:%d:%s", userName, host, port, sid);
	}

	public RdbaConnectionInfoEditor createEditor() {
		return new OracleRdbaConnectionInfoEditor();
	}

	public String[] toStringArray() {
		String[] result = {
			getClass().getCanonicalName(),
			"2",
			label,
			host,
			port.toString(),
			sid,
			userName,
			password,
		};
		return result;
	}
	
	public boolean restoreStringArray(String[] stringArray, int configRevision) {
		boolean result = false;
		if (stringArray[1].equals("1") && stringArray.length == 7) {
			host = stringArray[2];
			port = Integer.parseInt(stringArray[3]);
			sid = stringArray[4];
			userName = stringArray[5];
			password = stringArray[6];
			label = host+":"+sid;
			result = true;
		} else if (stringArray[1].equals("2") && stringArray.length == 8) {
			label = stringArray[2];
			host = stringArray[3];
			port = Integer.parseInt(stringArray[4]);
			sid = stringArray[5];
			userName = stringArray[6];
			password = stringArray[7];
			result = true;
		}
		return result;
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public String getHost() {
		return host;
	}
	public void setHost(String host) {
		this.host = host;
	}
	public Integer getPort() {
		return port;
	}
	public void setPort(Integer port) {
		this.port = port;
	}
	public String getSid() {
		return sid;
	}
	public void setSid(String sid) {
		this.sid = sid;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getPassword() {
		return password;
	}
	public void setPassword(String password) {
		this.password = password;
	}
}
